@@ -1,5 +1,5 @@
 #'@title Plot RRphylo rates at a specified node
-#'@usage plotRates(RR,node,export.tiff =TRUE,foldername)
+#'@usage plotRates(RR,node,export.tiff =FALSE,foldername=NULL,filename=NULL)
 #'@description The function \code{plotRates} plots the \code{\link{RRphylo}}
 #'  rates computed for a given clade as compared to the rates computed for the
 #'  rest of the tree.
@@ -7,7 +7,11 @@
 #'@param node the node subtending the clade of interest.
 #'@param export.tiff if \code{TRUE} the function save a "rate_bars.tiff" file
 #'  inside the working directory. It is \code{TRUE} by default.
-#'@param foldername the path of the folder where plots are to be found.
+#' @param foldername has been deprecated; please see the argument
+#'   \code{filename} instead.
+#' @param filename a character indicating the name of the tiff file and the path
+#'   where it is to be saved. If no path is indicated the file is stored in the
+#'   working directory.
 #'@export
 #' @seealso \href{../doc/RRphylo.html}{\code{RRphylo} vignette}
 #'@importFrom grDevices tiff
@@ -28,15 +32,20 @@
 #'
 #' RRphylo(tree=Tstage,y=PCstage,clus=cc)->RR
 #'
-#' plotRates(RR,node=72,foldername=tempdir(),export.tiff = TRUE)
+#' plotRates(RR,node=72,export.tiff = FALSE)
 #' }
 
 
 
 
-plotRates<-function(RR, node, export.tiff=TRUE,foldername){
+plotRates<-function(RR, node, export.tiff=FALSE,foldername=NULL,filename=NULL){
   #require(phytools)
 
+  if(!missing(foldername)){
+    stop("argument foldername is deprecated; please use filename instead.",
+         call. = FALSE)
+  }
+
   RR$rates->FULLrates
   RR$tree->rr3
   getDescendants(rr3,node)->shift331
@@ -48,15 +57,15 @@ plotRates<-function(RR, node, export.tiff=TRUE,foldername){
 
   if(export.tiff==TRUE)
   {
-    tiff(paste(foldername,"rate_bars.tiff",sep="/"),
+    tiff(paste(filename,".tiff",sep=""),
          width=2000,
          height=1500,
          pointsize=4,
          res=600,
          compression="lzw")
     par(mfrow=c(1,2))
-    hist(log(abs(shift.rates)))->H1
-    hist(log(abs(FULLrates[-match(names(shift.rates),rownames(FULLrates)),])))->H2
+    hist(log(abs(shift.rates)),plot=FALSE)->H1
+    hist(log(abs(FULLrates[-match(names(shift.rates),rownames(FULLrates)),])),plot=FALSE)->H2
     log(abs(FULLrates))[(log(abs(FULLrates))!="-Inf")]->Xa
     par(mar=c(4,4,4,4))
     plot(H2,col=rgb(0,1,0,.75),xlim=c(range(Xa)[1]-diff(range(Xa))*.1,range(Xa)[2]+diff(range(Xa))*.1),ylim=c(0,max(H2$count)*1.5),xlab="log absolute rates",main="")
@@ -68,12 +77,11 @@ plotRates<-function(RR, node, export.tiff=TRUE,foldername){
     abline(v=mean(FULLrates),col="red",lwd=3)
 
     dev.off()
-    return(shift.rates)
   }else{
 
     par(mfrow=c(1,2))
-    hist(log(abs(shift.rates)))->H1
-    hist(log(abs(FULLrates[-match(names(shift.rates),rownames(FULLrates)),])))->H2
+    hist(log(abs(shift.rates)),plot=FALSE)->H1
+    hist(log(abs(FULLrates[-match(names(shift.rates),rownames(FULLrates)),])),plot=FALSE)->H2
     log(abs(FULLrates))[(log(abs(FULLrates))!="-Inf")]->Xa
     par(mar=c(4,4,4,4))
     plot(H2,col=rgb(0,1,0,.75),xlim=c(range(Xa)[1]-diff(range(Xa))*.1,range(Xa)[2]+diff(range(Xa))*.1),ylim=c(0,max(H2$count)*1.3),xlab="log absolute rates",main="")
@@ -84,6 +92,6 @@ plotRates<-function(RR, node, export.tiff=TRUE,foldername){
     barplot(shift.rates,xlab="rates",horiz=TRUE,col="blue",names.arg=names(shift.rates), main="",border="red")
     abline(v=mean(FULLrates),col="red",lwd=3)
 
-    return(shift.rates)
   }
+  return(shift.rates)
 }
